@@ -116,13 +116,17 @@ def insert(period, period_steps, callback_id, callback, period_offset=0, from_no
 def remove(callback_id):
     global timer_table, memory_table, callback_table
     for period_info, period_data in timer_table.items():
+        to_del_ps = []
         for period_steps, callback_ids in period_data.items():
             if callback_id in callback_ids:
                 callback_ids.remove(callback_id)
             if callback_id in memory_table:
                 memory_table.pop(callback_id)
             if len(callback_ids) <= 0:
-                period_data.pop(period_steps)
+                to_del_ps.append(period_steps)
+        for period_steps in to_del_ps:
+            period_data.pop(period_steps)
+        del to_del_ps
         if not period_data:
             timer_table.pop(period_info)
     if callback_id in callback_table:
@@ -142,9 +146,8 @@ def get_actions(current_time):
         period_pointer = (current_time + period_offset) % period
         for period_steps, callback_ids in period_data.items():
             if STEP_TYPE_SET == period_steps[0] and period_pointer in period_steps[1:] or \
-                    STEP_TYPE_RANGE == period_steps[0] and period_pointer in range(*period_steps[1:]):
-                for callback_id in callback_ids:
-                    yield callback_id
+                                STEP_TYPE_RANGE == period_steps[0] and period_pointer in range(*period_steps[1:]):
+                yield from callback_ids
 
 
 def run_actions(current_time):
@@ -172,9 +175,9 @@ def run_actions_callback(*args, **kwargs):
     run_actions(current_time)
 
     stop = utime.ticks_ms()
-    time_task_calls = utime.ticks_diff(stop, start)
-    if time_task_calls > _max_time_task_calls:
-        e = TLPTimeException(current_time, time_task_calls, ' '.join(get_actions(current_time)))
+    processing_time = utime.ticks_diff(stop, start)
+    if processing_time > _max_time_task_calls:
+        e = TLPTimeException(current_time, processing_time, ' '.join(get_actions(current_time)))
         for processor in callback_exception_processors:
             processor(e)
 
